==> react-object-mapper-1.0.3.tgz: package/README.md <==
![NPM](https://img.shields.io/npm/l/@vm-lib/react-object-mapper)
![npm](https://img.shields.io/npm/v/@vm-lib/react-object-mapper)

# **react-object-mapper**

#### This library is used for copying properties from a source object to a destination object, with configurations options based on which the library chooses to copy, skip or merge certain properties.

## **Download**

`react-object-mapper` is available at npm and you can download it to your react project by running the following command.

```javascript
npm install --save @vm-lib/react-object-mapper
```

## **Import**

```javascript
import * as ObjectMapper from "@vm-lib/react-object-mapper/om/ObjectMapper";
```

## **Basic Usage**

In it's most basic form, the object mapper can be used to make a deep copy of an object.

`ObjectMapper.copyProperties(<srcObj>, <targetObj> [,<objectMappingObj>])`

`copyProperties` always returns a new object. It takes at a _minimum_ a `source_object` & a `target_object` as params. The target object can be an empty object for the basic copy, or can be an existing object into which properties from the `source_object` have to be copied or merged..

```javascript
import * as ObjectMapper from "@vm-lib/react-object-mapper/om/ObjectMapper";

let src = {
  prop1: "val1",
  prop2: "val2",
};
let target = {};
let enrichedObj = ObjectMapper.copyProperties(src, target);
// ----------- Output -----------
// enrichedObj =
{
    prop1:"val1",
    prop2:"val2",
}
```

## **Options**

1. Copy All [Default Mode]

```javascript
let src = {
  prop1: "val1",
  prop2: "val2",
};
let target = {};

let enrichedObj = ObjectMapper.copyProperties(src, target, {
  [ObjectMapper.PROP_PROPERTIES]: ObjectMapper.PROPS_MAP_DEFAULT,
});
```

```javascript
//the output object
{
    prop1:"val1",
    prop2:"val2",
}
```

2. Copy only specific properties [Strict Mode]
3. Merge i.e. copy only those properties from the source whose values are empty in the target

## **License**

Apache-2

==> react-object-mapper-1.0.4.tgz: package/README.md <==
![NPM](https://img.shields.io/npm/l/@vm-lib/react-object-mapper)
![npm](https://img.shields.io/npm/v/@vm-lib/react-object-mapper)

# **react-object-mapper**

#### This library is used for copying properties from a source object to a destination object, with configurations options based on which the library chooses to copy, skip or merge certain properties.

## **Download**

`react-object-mapper` is available at npm and you can download it to your react project by running the following command.

```javascript
npm install --save @vm-lib/react-object-mapper
```

## **Import**

```javascript
import ObjectMapper from "@vm-lib/react-object-mapper/om/ObjectMapper";
```

## **Basic Usage**

In it's most basic form, the object mapper can be used to make a deep copy of an object.

`ObjectMapper.copyProperties(<srcObj>, <targetObj> [,<objectMappingObj>])`

`copyProperties` always returns a new object. It takes at a _minimum_ a `source_object` & a `target_object` as params. The target object can be an empty object for the basic copy, or can be an existing object into which properties from the `source_object` have to be copied or merged..

```javascript
import ObjectMapper from "@vm-lib/react-object-mapper/om/ObjectMapper";

let src = {
  prop1: "val1",
  prop2: "val2",
};
let target = {};
let enrichedObj = ObjectMapper.copyProperties(src, target);
// ----------- Output -----------
// enrichedObj =
{
    prop1:"val1",
    prop2:"val2",
}
```

## **Sandbox**

#### The sandbox is available here: [react-object-mapper-sandbox](https://codesandbox.io/s/react-object-mapper-sandbox-6s82n?file=/src/App.js)


## **Options**

1. Copy All [Default Mode]

```javascript
let src = {
  prop1: "val1",
  prop2: "val2",
};
let target = {};

let enrichedObj = ObjectMapper.copyProperties(src, target, {
  [ObjectMapper.PROP_PROPERTIES]: ObjectMapper.PROPS_MAP_DEFAULT,
});
```

```javascript
//the output object
{
    prop1:"val1",
    prop2:"val2",
}
```

2. Copy only specific properties [Strict Mode]
3. Merge i.e. copy only those properties from the source whose values are empty in the target

## **License**

Apache-2
